import pathlib

from injector import Injector
import wksp.workflow as wf
import wksp.capability as cp
from wksp.ifaces import WorkflowInfo, WorkflowService, CapabilityService
import sys


def main():
    if len(sys.argv) < 2:
        print('Usage: run <capability name> product-locator [product-locator...]')

    # for the purposes of this test, we are using
    # the hardcoded workflow info and the DAGman workflow service
    def configure(binder):
        # binder.bind(CapabilityInfo, to=cp.DirectoryCapabilityInfo(pathlib.Path('./capabilities'))
        # binder.bind(CapabilityEngineResponder, to=cp.ConsoleEngineResponder)
        binder.bind(WorkflowInfo,                 to=wf.DirectoryWorkflowInfo(pathlib.Path('./workflows')))
        binder.bind(WorkflowService,              to=wf.HTCondorWorkflowService)
        binder.bind(cp.CapabilityInfoIF, to=cp.DirectoryCapabilityInfo(pathlib.Path('./capabilities')))
        binder.bind(CapabilityService,            to=cp.PrototypeCapabilityService)
        binder.bind(cp.ProductServiceIF, to=cp.HardcodedProductService)
        binder.bind(cp.CapabilityEngineIF, to=cp.PrototypeCapabilityEngine)
        binder.bind(cp.CapabilityEngineResponderIF, to=cp.PrototypeCapabilityEngineResponder)
        binder.bind(cp.CapabilityQueueIF, to=cp.PrototypeCapabilityQueue)

    # set up the injector
    injector = Injector(configure)

    # get the service
    capability_service = injector.get(CapabilityService)

    # 1. initialize the request
    request = capability_service.send_request(sys.argv[1], sys.argv[2:])

    # 2. execute the request
    capability_service.execute(request)

    # 3. while the request needs input, provide it
